### Metadata Editor

The metadata editor lists all the _data labels_ of the uploaded additional metadata. Data labels define the uploaded data in a structured way.

#### Datatype selectors

Datatypes define how the data can be compared and manipulated. The datatype of each label will be inferred by the Corpus Loader, but they can be changed as needed. Some values aren't compatible with some data types. For instance, "hello" cannot be interpreted as an integer. The most general data type (compatible with the most values) is text.

#### Include checkbox

The include checkbox indicates whether a data label will be included in the corpus. By default, all metadata is not included. Check the box for a data label to include its data in the corpus.

#### Link indicator

When additional metadata is loaded, the **Corpus Editor** and the **Metadata Editor** display a _link_ indicator next to the linked data labels, which looks like this: 🔗

Both the **Corpus Editor** and the **Metadata Editor** must have a linked data label before the corpus can be built. You can select linking data labels using the selector dropdowns between the **Corpus Editor** and **Metadata Editor**.